==> IceWarpServer-9.3.2_RHEL4.tar.gz: html/webmail/client/inc/obj_select_input.js <==
_me = obj_select_input.prototype;
function obj_select_input(){};

	_me.__constructor = function(){
		var me = this;
		/* options visibility */
        this.__sValue = '';

		this.__eInput  = this._getAnchor('input');
		this.__eInput = this.__eInput.form[this.__eInput.name];
        this.__eInput.setAttribute('autocomplete',"off");

		this.__eInput.onfocus = function(e){
			if (me.__hideTimeout) window.clearTimeout(me.__hideTimeout);
		};
		/*
		this.__eInput._value = function(v){
			if (Is.Defined(v))
			    this.value = v.toString().unescapeHTML();
			else
			    return this.value.toString().escapeHTML();
		};
		*/

        this.__eInput.onkeydown = function(e){
            var e = e || window.event;
			var elm = e.target || e.srcElement;
			
			switch(e.keyCode){
			//UP
			case 38:
			
			    break;
			//DN
			case 40:

			}
		};

		this.__eInput.onkeyup = function(e){

			var key = -1;
			for(var i in me.__idTable)
				if(me.__idTable[i]==this._value()) key = i;

			if (key != -1) me.__value(key);
		};

		this.__eInput.onchange = function(e){
			if (typeof me.__idTable[me.__sValue] != 'undefined' && me.__idTable[me.__sValue] == this._value())
				return;

			if (me.__sValue == this._value()) return;

			me._value(this._value());
		};

        this.__eInput.onblur = function(e){
			me.__hideTimeout = window.setTimeout('try{'+me._pathName + '.__hide();}catch(err){}',150);
		};

		this.__eButton.onblur = null;
        
        
		this.__eButton.onfocus = function(e){
            me.__eInput.focus();
		};
		
        this.__eButton.onkeydown = function(e){

			if(me.__disabled) return false;

			var e = e || window.event;
			var elm = e.target || e.srcElement;
			/*
			e.cancelBubble = true;
			if (e.stopPropagation) e.stopPropagation();
			 */

			//prepare ids
			if (e.keyCode == 38 || e.keyCode == 40){

				var before,myself,after, v = me.__value();
				
				//If actual value is different (user specified) than available values in pulldown
				//then try to finde similar one
				for (var i in me.__idTable){
					if  (i != v){
						if  (typeof myself == 'undefined')
							before = i;
						else{
							after = i;
							break;
						}
					}
					else
					    myself = i;
				}
			}

			switch(e.keyCode){
			//Up
			case 38:
					if (typeof myself != 'undefined' && typeof before != 'undefined') me.__value(before);
                    return false;
			//Down
			case 40:
					if (typeof myself != 'undefined' && typeof after != 'undefined') me.__value(after);
					return false;
			//Enter
			case 13:
					if (!me.__visibleOptions){
                        me.__show();
						return false;
					}
			//Esc
			case 27:
					me.__hide();
					return false;
					break;
			}
		};
	};

	_me.__show = function(){

        //if (this.__hideTimeout) window.clearTimeout(this.__hideTimeout);

		this.__eInput.focus();
		
        this.__createOptionList();

		this.__visibleOptions = true;

		var pos = getSize(this._main);

		this.__eOptions.style.width = pos.w + 'px';
		this.__eOptions.style.top   = (pos.y+pos.h) + 'px';
		this.__eOptions.style.left 	= pos.x + 'px';
		this.__eOptions.className = this._main.className + ' obj_select_options';
		this.__eOptions.style.display = 'block';

		if (count(this.__idTable)>10){
            this.__eOptions.style.overflow = 'auto';

            var size = 0;
			try{
            	size = getSize(this.__eOptions.getElementsByTagName('A')[0]).h*10;
			}
			catch(er){
				size = 153;
			}

			this.__eOptions.style.height = size +'px';
		}
		else{
            this.__eOptions.style.overflow = 'visible';
            this.__eOptions.style.height = 'auto';
		}

		this.__activate();
	};
	
	_me.__value = function(sData,bNoEvn) {
		// return
		if (typeof sData == 'undefined') return this.__sValue;
		// set   ||
        if (this.__sValue == sData) return;

		if (typeof this.__idTable[sData] == 'undefined')
			this.__eInput.value = sData;
		else
            this.__eInput.value = this.__idTable[sData];

        this.__activate(sData);
		this.__sValue = sData;

		if (!bNoEvn){
			// onchange event
	        if(this._onchange) this._onchange(null);
		    this.__exeEvent('onchange',null,{"owner":this});
	    }
	};

	_me._value = function(sData,bNoEvn) {
		return this.__value(sData,bNoEvn);
	};
	
	_me.__activate = function(key){
		var elm;

		if  (this.__tempValue){
			if ((elm = document.getElementById(this._pathName+this.__tempValue)))
				removecss(elm,'active');
			this.__tempValue = '';
		}
        //alert(this.__eOptions.innerHTML);
		if (this.__sValue && (elm = document.getElementById(this._pathName+this.__sValue))){
			if (typeof key == 'undefined'){
				addcss(elm,'active');

				// scroll to value
				if (elm.offsetTop>this.__eOptions.scrollTop+this.__eOptions.clientHeight || elm.offsetTop<this.__eOptions.scrollTop)
					this.__eOptions.scrollTop = elm.offsetTop - (this.__eOptions.clientHeight/2);

				return;
			}
			else
				removecss(elm,'active');
		}

		if (typeof key != 'undefined' && (elm = document.getElementById(this._pathName+key))){
			addcss(elm,'active');

			//document.title = 'scroll';
			// scroll to value
			if (elm.offsetTop<this.__eOptions.scrollTop)
				this.__eOptions.scrollTop = elm.offsetTop+1;
			else
			if (elm.offsetTop+elm.offsetHeight>this.__eOptions.clientHeight+this.__eOptions.scrollTop)
				this.__eOptions.scrollTop = elm.offsetTop+elm.offsetHeight - this.__eOptions.clientHeight-1;
		}
	};

==> IceWarpServer-9.4.2_RHEL4.tar.gz: html/webmail/client/inc/obj_select_input.js <==
_me = obj_select_input.prototype;
function obj_select_input(){};

	_me.__constructor = function(){
		var me = this;
		/* options visibility */
        this.__sValue = '';

		this.__eInput  = this._getAnchor('input');
		this.__eInput = this.__eInput.form[this.__eInput.name];
        this.__eInput.setAttribute('autocomplete',"off");

		this.__eInput.onfocus = function(e){
			if (me.__hideTimeout) window.clearTimeout(me.__hideTimeout);
		};
		/*
		this.__eInput._value = function(v){
			if (Is.Defined(v))
			    this.value = v.toString().unescapeHTML();
			else
			    return this.value.toString().escapeHTML();
		};
		*/

        this.__eInput.onkeydown = function(e){
            var e = e || window.event;
			var elm = e.target || e.srcElement;
			
			switch(e.keyCode){
			//UP
			case 38:
			
			    break;
			//DN
			case 40:

			}
		};

		this.__eInput.onkeyup = function(e){

			var key = -1;
			for(var i in me.__idTable)
				if(me.__idTable[i]==this._value()) key = i;

			if (key != -1) me.__value(key);
		};

		this.__eInput.onchange = function(e){
			if (typeof me.__idTable[me.__sValue] != 'undefined' && me.__idTable[me.__sValue] == this._value())
				return;

			if (me.__sValue == this._value()) return;

			me._value(this._value());
		};

        this.__eInput.onblur = function(e){
			me.__hideTimeout = window.setTimeout('try{'+me._pathName + '.__hide();}catch(err){}',150);
		};

		this.__eButton.onblur = null;
        
        
		this.__eButton.onfocus = function(e){
            me.__eInput.focus();
		};
		
        this.__eButton.onkeydown = function(e){

			if(me.__disabled) return false;

			var e = e || window.event;
			var elm = e.target || e.srcElement;
			/*
			e.cancelBubble = true;
			if (e.stopPropagation) e.stopPropagation();
			 */

			//prepare ids
			if (e.keyCode == 38 || e.keyCode == 40){

				var before,myself,after, v = me.__value();
				
				//If actual value is different (user specified) than available values in pulldown
				//then try to finde similar one
				for (var i in me.__idTable){
					if  (i != v){
						if  (typeof myself == 'undefined')
							before = i;
						else{
							after = i;
							break;
						}
					}
					else
					    myself = i;
				}
			}

			switch(e.keyCode){
			//Up
			case 38:
					if (typeof myself != 'undefined' && typeof before != 'undefined') me.__value(before);
                    return false;
			//Down
			case 40:
					if (typeof myself != 'undefined' && typeof after != 'undefined') me.__value(after);
					return false;
			//Enter
			case 13:
					if (!me.__visibleOptions){
                        me.__show();
						return false;
					}
			//Esc
			case 27:
					me.__hide();
					return false;
					break;
			}
		};
	};

	_me.__show = function(){

        if (this.__hideTimeout)
			window.clearTimeout(this.__hideTimeout);

		if (!this.__createOptionList())
		    return;

		this.__eInput.focus();
		
		this.__visibleOptions = true;

		var pos = getSize(this._main);

		this.__eOptions.style.width = pos.w + 'px';
		this.__eOptions.style.top   = (pos.y+pos.h) + 'px';
		this.__eOptions.style.left 	= pos.x + 'px';

		this.__eOptions.style.display = 'block';

		if (count(this.__idTable)>10){
            this.__eOptions.style.overflow = 'auto';

            var size = 0;
			try{
            	size = getSize(this.__eOptions.getElementsByTagName('A')[0]).h*10;
			}
			catch(er){
				size = 153;
			}

			this.__eOptions.style.height = size +'px';
		}
		else{
            this.__eOptions.style.overflow = 'visible';
            this.__eOptions.style.height = 'auto';
		}

		this.__activate();
	};
	
	_me.__value = function(sData,bNoEvn) {
		// return
		if (typeof sData == 'undefined') return this.__sValue;
		// set   ||
        if (this.__sValue == sData) return;

		if (typeof this.__idTable[sData] == 'undefined')
			this.__eInput.value = sData;
		else
            this.__eInput.value = this.__idTable[sData];

        this.__activate(sData);
		this.__sValue = sData;

		if (!bNoEvn){
			// onchange event
	        if(this._onchange) this._onchange(null);
		    this.__exeEvent('onchange',null,{"owner":this});
	    }
	};

	_me._value = function(sData,bNoEvn) {
		return this.__value(sData,bNoEvn);
	};
	
	_me.__activate = function(key){

        if (!this.__eOptions) return;
        		
		var elm;

		if  (this.__tempValue){
			if ((elm = document.getElementById(this._pathName+this.__tempValue)))
				removecss(elm,'active');
			this.__tempValue = '';
		}
        //alert(this.__eOptions.innerHTML);
		if (this.__sValue && (elm = document.getElementById(this._pathName+this.__sValue))){
			if (typeof key == 'undefined'){
				addcss(elm,'active');

				// scroll to value
				if (elm.offsetTop>this.__eOptions.scrollTop+this.__eOptions.clientHeight || elm.offsetTop<this.__eOptions.scrollTop)
					this.__eOptions.scrollTop = elm.offsetTop - (this.__eOptions.clientHeight/2);

				return;
			}
			else
				removecss(elm,'active');
		}

		if (typeof key != 'undefined' && (elm = document.getElementById(this._pathName+key))){
			addcss(elm,'active');

			//document.title = 'scroll';
			// scroll to value
			if (elm.offsetTop<this.__eOptions.scrollTop)
				this.__eOptions.scrollTop = elm.offsetTop+1;
			else
			if (elm.offsetTop+elm.offsetHeight>this.__eOptions.clientHeight+this.__eOptions.scrollTop)
				this.__eOptions.scrollTop = elm.offsetTop+elm.offsetHeight - this.__eOptions.clientHeight-1;
		}
	};
